package com.redhat.thermostat.tools.eclipse.plugin.tests.model;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.util.List;

import org.junit.Test;

import com.redhat.thermostat.tools.eclipse.plugin.model.Bundle;
import com.redhat.thermostat.tools.eclipse.plugin.model.Command;
import com.redhat.thermostat.tools.eclipse.plugin.model.Extension;
import com.redhat.thermostat.tools.eclipse.plugin.model.Plugin;
import com.redhat.thermostat.tools.eclipse.plugin.model.PluginModelReaderWriter;

public class PluginModelReaderWriterTest {

    @Test
    public void testParsingCommand() {
        String document = "<?xml version='1.0'?>\n"
                + "<plugin xmlns=\"http://icedtea.classpath.org/thermostat/plugins/v1.0\"\n"
                + "    xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n"
                + "    xsi:schemaLocation=\"http://icedtea.classpath.org/thermostat/plugins/v1.0 thermostat-plugin.xsd\">\n"
                + "  <commands>\n"
                + "    <command>\n"
                + "      <name>foo</name>\n"
                + "      <usage>foo bar</usage>\n"
                + "      <description>foos the bar if possible</description>\n"
                + "      <arguments>\n"
                + "        <argument>bar</argument>\n"
                + "      </arguments>\n"
                + "      <options>\n"
                + "        <option>\n"
                + "        </option>\n"
                + "      </options>\n"
                + "      <environments>\n"
                + "        <environment>cli</environment>\n"
                + "      </environments>\n"
                + "      <bundles>\n"
                + "        <bundle><symbolic-name>foo</symbolic-name><version>1</version></bundle>\n"
                + "      </bundles>\n"
                + "    </command>\n"
                + "  </commands>\n"
                + "</plugin>\n";

        PluginModelReaderWriter pluginModel = new PluginModelReaderWriter(null, "<stdin>");
        Plugin model = pluginModel.loadModel(document);

        Command foo = model.getCommands().get(0);

        assertNotNull(foo);

        assertEquals("foo", foo.getName());
        assertEquals("foo bar", foo.getUsage());
        assertEquals("foos the bar if possible", foo.getDescription());

        assertTrue(foo.getEnvironments().isCli());
        assertFalse(foo.getEnvironments().isShell());

        List<Bundle> bundles = foo.getBundles();
        assertEquals(1, bundles.size());

        Bundle bundle = bundles.get(0);
        assertEquals("foo", bundle.getSymbolicName());
        assertEquals("1", bundle.getVersion());
    }

    @Test
    public void testBinding() {
        String document = "<?xml version='1.0'?>\n"
                + "<plugin xmlns=\"http://icedtea.classpath.org/thermostat/plugins/v1.0\"\n"
                + "    xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n"
                + "    xsi:schemaLocation=\"http://icedtea.classpath.org/thermostat/plugins/v1.0 thermostat-plugin.xsd\">\n"
                + "  <extensions>\n"
                + "    <extension>\n"
                + "      <name>foo</name>\n"
                + "      <bundles>\n"
                + "        <bundle><symbolic-name>foo</symbolic-name><version>1</version></bundle>\n"
                + "      </bundles>\n"
                + "    </extension>\n"
                + "  </extensions>\n"
                + "</plugin>\n";

        PluginModelReaderWriter model = new PluginModelReaderWriter(null, "stdin");
        Plugin plugin = model.loadModel(document);

        List<Extension> extensions = plugin.getExtensions();
        assertEquals(1, extensions.size());
    }
}
